@@ -499,7 +499,7 @@ void MenuStateOptionsNetwork::render(){
 
 	}
 
-	renderer.renderConsole(&console,false,true);
+	renderer.renderConsole(&console);
 	if(program != NULL) program->renderProgramMsgBox();
 }
 
