@@ -16,6 +16,8 @@
 #include "game_constants.h"
 #include "network_types.h"
 #include "byte_order.h"
+#include <map>
+
 #include "leak_dumper.h"
 
 using Shared::Platform::Socket;
@@ -65,15 +67,52 @@ static const int maxLanguageStringSize= 60;
 //	class NetworkMessage
 // =====================================================
 
+enum NetworkMessageStatisticType {
+	netmsgstPacketsPerMillisecondSend,
+	netmsgstPacketsPerMillisecondSend_current_count,
+	netmsgstPacketsPerMillisecondSend_last,
+
+	netmsgstPacketsPerSecondSend,
+	netmsgstPacketsPerSecondSend_current_count,
+	netmsgstPacketsPerSecondSend_last,
+
+	netmsgstAverageSendSize,
+
+	// ---------------------------------------------
+	netmsgstPacketsPerMillisecondRecv,
+	netmsgstPacketsPerMillisecondRecv_current_count,
+	netmsgstPacketsPerMillisecondRecv_last,
+
+	netmsgstPacketsPerSecondRecv,
+	netmsgstPacketsPerSecondRecv_current_count,
+	netmsgstPacketsPerSecondRecv_last,
+
+	netmsgstAverageRecvSize,
+
+	netmsgstLastEvent
+
+};
+
 class NetworkMessage {
+private:
+
+	static auto_ptr<Mutex> mutexMessageStats;
+	static Chrono statsTimer;
+	static Chrono lastSend;
+	static Chrono lastRecv;
+	static std::map<NetworkMessageStatisticType,int64> mapMessageStats;
+
 public:
+	static void resetNetworkPacketStats();
+	static string getNetworkPacketStats();
+
 	static bool useOldProtocol;
 	virtual ~NetworkMessage(){}
 	virtual bool receive(Socket* socket)= 0;
 	virtual void send(Socket* socket) = 0;
 	virtual size_t getDataSize() const = 0;
 
-	void dump_packet(string label, const void* data, int dataSize);
+	void dump_packet(string label, const void* data, int dataSize, bool isSend);
 
 protected:
 	//bool peek(Socket* socket, void* data, int dataSize);
@@ -98,6 +137,7 @@ class NetworkMessageIntro: public NetworkMessage{
 private:
 	static const int maxVersionStringSize= 128;
 	static const int maxNameSize= 32;
+	static const int maxSmallStringSize= 60;
 
 private:
 	struct Data {
@@ -110,6 +150,9 @@ private:
 		uint32 externalIp;
 		uint32 ftpPort;
 		NetworkString<maxLanguageStringSize> language;
+		int8 gameInProgress;
+		NetworkString<maxSmallStringSize> playerUUID;
+		NetworkString<maxSmallStringSize> platform;
 	};
 	void toEndian();
 	void fromEndian();
@@ -123,7 +166,8 @@ public:
 	NetworkMessageIntro();
 	NetworkMessageIntro(int32 sessionId, const string &versionString,
 			const string &name, int playerIndex, NetworkGameStateType gameState,
-			uint32 externalIp, uint32 ftpPort, const string &playerLanguage);
+			uint32 externalIp, uint32 ftpPort, const string &playerLanguage,
+			int gameInProgress, const string &playerUUID, const string &platform);
 
 
 	virtual const char * getPackedMessageFormat() const;
@@ -142,6 +186,10 @@ public:
 	uint32 getExternalIp() const                { return data.externalIp;}
 	uint32 getFtpPort() const					{ return data.ftpPort; }
 	string getPlayerLanguage() const			{ return data.language.getString(); }
+	uint8 getGameInProgress() const				{ return data.gameInProgress; }
+
+	string getPlayerUUID() const				{ return data.playerUUID.getString();}
+	string getPlayerPlatform() const			{ return data.platform.getString();}
 
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
@@ -186,6 +234,7 @@ public:
 	int32 getPingFrequency() const	{return data.pingFrequency;}
 	int64 getPingTime() const	{return data.pingTime;}
 	int64 getPingReceivedLocalTime() const { return pingReceivedLocalTime; }
+	void setPingReceivedLocalTime(int64 pingTime)  { pingReceivedLocalTime = pingTime; }
 
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
@@ -253,6 +302,7 @@ private:
 		NetworkString<maxSmallStringSize> tech;
 		NetworkString<maxSmallStringSize> factionTypeNames[GameConstants::maxPlayers]; //faction names
 		NetworkString<maxSmallStringSize> networkPlayerNames[GameConstants::maxPlayers]; //networkPlayerNames
+		NetworkString<maxSmallStringSize> networkPlayerPlatform[GameConstants::maxPlayers];
 		int32 networkPlayerStatuses[GameConstants::maxPlayers]; //networkPlayerStatuses
 		NetworkString<maxSmallStringSize> networkPlayerLanguages[GameConstants::maxPlayers];
 
@@ -269,6 +319,7 @@ private:
 		int8 factionCount;
 		int8 teams[GameConstants::maxPlayers];
 		int8 startLocationIndex[GameConstants::maxPlayers];
+
 		int8 defaultResources;
         int8 defaultUnits;
         int8 defaultVictoryConditions;
@@ -287,6 +338,11 @@ private:
 		int32 masterserver_admin_factionIndex;
 
 		NetworkString<maxStringSize> scenario;
+
+		NetworkString<maxSmallStringSize> networkPlayerUUID[GameConstants::maxPlayers];
+
+		int8 networkAllowNativeLanguageTechtree;
+		NetworkString<maxSmallStringSize> gameUUID;
 	};
 	void toEndian();
 	void fromEndian();
@@ -328,23 +384,28 @@ public:
 #pragma pack(push, 1)
 class NetworkMessageCommandList: public NetworkMessage {
 
-private:
-	//static const int maxCommandCount = 2496; // can be as large as 65535
-
 private:
 	struct DataHeader {
 		int8 messageType;
 		uint16 commandCount;
 		int32 frameCount;
+		uint32 networkPlayerFactionCRC[GameConstants::maxPlayers];
 	};
 
 	static const int32 commandListHeaderSize = sizeof(DataHeader);
 
 	struct Data {
 		DataHeader header;
-		//NetworkCommand commands[maxCommandCount];
 		std::vector<NetworkCommand> commands;
 	};
+	void init(Data &data_ref) {
+		data_ref.header.messageType = 0;
+		data_ref.header.commandCount = 0;
+		data_ref.header.frameCount = 0;
+		for(int index = 0; index < GameConstants::maxPlayers; ++index) {
+			data_ref.header.networkPlayerFactionCRC[index] = 0;
+		}
+	}
 	void toEndianHeader();
 	void fromEndianHeader();
 	void toEndianDetail(uint16 totalCommand);
@@ -376,9 +437,12 @@ public:
 
 	bool addCommand(const NetworkCommand* networkCommand);
 
-	void clear()									{data.header.commandCount= 0;}
-	int getCommandCount() const						{return data.header.commandCount;}
-	int getFrameCount() const						{return data.header.frameCount;}
+	void clear()										{data.header.commandCount= 0;}
+	int getCommandCount() const							{return data.header.commandCount;}
+	int getFrameCount() const							{return data.header.frameCount;}
+	uint32 getNetworkPlayerFactionCRC(int index) const  {return data.header.networkPlayerFactionCRC[index];}
+	void setNetworkPlayerFactionCRC(int index, uint32 crc) { data.header.networkPlayerFactionCRC[index]=crc;}
+
 	const NetworkCommand* getCommand(int i) const	{return &data.commands[i];}
 
 	virtual bool receive(Socket* socket);
@@ -575,7 +639,7 @@ private:
 
 static const int maxStringSize= 255;
 static const int maxFileCRCCount= 1500;
-static const int maxFileCRCPacketCount= 25;
+static const uint32 maxFileCRCPacketCount= 25;
 
 private:
 
@@ -760,8 +824,8 @@ private:
 	struct Data {
 		int8 messageType;
 		NetworkString<maxStringSize> selectedFactionName; //wanted faction name
-		int8 currentFactionIndex;
-		int8 toFactionIndex;
+		int8 currentSlotIndex;
+		int8 toSlotIndex;
 		int8 toTeam;
 		NetworkString<maxPlayernameStringSize> networkPlayerName;
 		int8 networkPlayerStatus;
@@ -790,8 +854,8 @@ public:
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
 	string getSelectedFactionName() const	{return data.selectedFactionName.getString();}
-	int getCurrentFactionIndex() const		{return data.currentFactionIndex;}
-	int getToFactionIndex() const			{return data.toFactionIndex;}
+	int getCurrentSlotIndex() const		{return data.currentSlotIndex;}
+	int getToSlotIndex() const			{return data.toSlotIndex;}
 	int getToTeam() const					{return data.toTeam;}
 	string getNetworkPlayerName() const		{return data.networkPlayerName.getString(); }
 	int getSwitchFlags() const				{return data.switchFlags;}
@@ -986,7 +1050,7 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-	NetworkMessageUnMarkCell(){}
+	NetworkMessageUnMarkCell();
 	NetworkMessageUnMarkCell(Vec2i target, int factionIndex);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
@@ -1033,7 +1097,7 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-	NetworkMessageHighlightCell(){}
+	NetworkMessageHighlightCell();
 	NetworkMessageHighlightCell(Vec2i target, int factionIndex);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
