@@ -12,11 +12,17 @@
 	// consider replacing this by a cron job
 	cleanupServerList();
 
-	$servers_in_db = mysql_query( 'SELECT * FROM glestserver ORDER BY status, connectedClients>0 DESC, (networkSlots - connectedClients) , ip DESC;' );
+	$servers_in_db = mysql_query( 'SELECT a.*,b.framesToCalculatePlaytime FROM glestserver a LEFT JOIN glestgamestats b ON a.gameUUID = b.gameUUID WHERE status <> 3 OR (status = 3 AND a.lasttime > DATE_add(NOW(), INTERVAL - ' . MAX_HOURS_OLD_GAMES . ' hour)) ORDER BY status, a.lasttime DESC, connectedClients > 0 DESC, (networkSlots - connectedClients), ip DESC;' );
 	$all_servers = array();
 	while ( $server = mysql_fetch_array( $servers_in_db ) )
 	{
+	        // Game Stats
+                $rowIndex = count($all_servers);
+                $gameDuration = $server["framesToCalculatePlaytime"];
+                $server["gameDuration"] = getTimeString($gameDuration);
+
 		array_push( $all_servers, $server );
+
 	}
 	unset( $servers_in_db );
 	unset( $server );
@@ -24,6 +30,7 @@
 	db_disconnect( DB_LINK );
 	unset( $linkid );
 
+        header('Content-type: application/json');
 	echo json_encode($all_servers);
 	unset( $all_servers );
 ?>
