@@ -35,6 +35,11 @@ public:
 	void makeCurrentGl();
 	void swapBuffersGl();
 	void setGamma(float gammaValue){context.setGammaValue(gammaValue);}
+
+	virtual bool ChangeVideoMode(bool preserveContext, int resWidth, int resHeight,
+			bool fullscreenWindow, int colorBits, int depthBits, int stencilBits,
+            bool hardware_acceleration, bool fullscreen_anti_aliasing,
+            float gammaValue);
 };
 
 }}//end namespace
