@@ -163,6 +163,8 @@ static inline void loadTexture(class ctx *ctx) {
    glTexImage2D(GL_TEXTURE_2D, 0, 4, ctx->width, ctx->height, 0, GL_RGBA, GL_UNSIGNED_BYTE, (Uint8 *) rawData);
 }
 
+#ifdef HAS_LIBVLC
+#if !defined(LIBVLC_VERSION_PRE_2) && !defined(LIBVLC_VERSION_PRE_1_1_0)
 static void *lock(void *data, void **p_pixels) {
     class ctx *ctx = (class ctx *)data;
     if(ctx->verboseEnabled) printf("In [%s] Line: %d\n",__FUNCTION__,__LINE__);
@@ -188,6 +190,8 @@ static void display(void *data, void *id) {
     class ctx *ctx = (class ctx *)data;
     if(ctx->verboseEnabled) printf("In [%s] Line: %d\n",__FUNCTION__,__LINE__);
 }
+#endif
+#endif
 
 #if defined(HAS_LIBVLC) && defined(LIBVLC_VERSION_PRE_2) && defined(LIBVLC_VERSION_PRE_1_1_0)
 static void catchError(libvlc_exception_t *ex) {
@@ -463,8 +467,9 @@ bool VideoPlayer::hasBackEndVideoPlayer() {
 
 #ifdef HAS_LIBVLC
 	return true;
-#endif
+#else
 	return false;
+#endif
 }
 
 void VideoPlayer::cleanupPlayer() {
@@ -550,7 +555,7 @@ bool VideoPlayer::initPlayer(string mediaURL) {
 #if defined(WIN32)
 	if(verboseEnabled) _putenv("VLC_VERBOSE=2");
 #endif
-	int vlc_argc = ctxPtr->vlc_argv.size();
+
 
 //	char const *vlc_argv[] =
 //	{
@@ -590,6 +595,7 @@ bool VideoPlayer::initPlayer(string mediaURL) {
 	ctxPtr->libvlc = libvlc_new(ctxPtr->vlc_argc, &ctxPtr->vlc_argv[0],&ex);
 	catchError(&ex);
 #else
+	int vlc_argc = ctxPtr->vlc_argv.size();
 	ctxPtr->libvlc = libvlc_new(vlc_argc, &ctxPtr->vlc_argv[0]);
 #endif
 
@@ -1317,11 +1323,13 @@ bool VideoPlayer::playFrame(bool swapBuffers) {
 		return false;
 	}
 
-	int action = 0, pause = 0, n = 0;
 	if(successLoadingLib == true &&
 		ctxPtr != NULL && ctxPtr->isPlaying == true &&
 		finished == false && stop == false) {
-		action = 0;
+
+		//int action = 0, pause = 0, n = 0;
+		//int action = 0, n = 0;
+		int action = 0;
 
 		SDL_Event event;
 		/* Keys: enter (fullscreen), space (pause), escape (quit) */
@@ -1351,14 +1359,14 @@ bool VideoPlayer::playFrame(bool swapBuffers) {
 				//screen = SDL_SetVideoMode(WIDTH, HEIGHT, 0, options);
 				finished = true;
 				break;
-			case ' ':
-				//pause = !pause;
-				break;
+			//case ' ':
+			//	//pause = !pause;
+			//	break;
 			}
 
-			if(pause == 0) {
-				n++;
-			}
+			//if(pause == 0) {
+			//n++;
+			//}
 
 		    //assertGl();
 
@@ -1413,7 +1421,12 @@ bool VideoPlayer::playFrame(bool swapBuffers) {
 		}
 	}
 
-	return ctxPtr->needToQuit;
+	if(ctxPtr != NULL) {
+		return ctxPtr->needToQuit;
+	}
+	else {
+		return false; 
+	}
 }
 
 void VideoPlayer::RestartVideo() {
